==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/views/draw/DrawFeedVideoViewFactory.java <==
package com.yifan.yf_ads.views.draw;

import android.app.Activity;
import android.content.Context;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.yifan.yf_ads.bean.DrawFeedVideoBean;
import com.yifan.yf_ads.utils.Constants;
import com.yifan.yf_ads.utils.FLog;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.StandardMessageCodec;
import io.flutter.plugin.platform.PlatformView;
import io.flutter.plugin.platform.PlatformViewFactory;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/26 14:38
 **/
public class DrawFeedVideoViewFactory extends PlatformViewFactory {
    private EventChannel.EventSink eventSink;
    private Activity activity;
    private final String TAG = "DrawFeedVideoViewFactory";
    private Map<Integer, DrawFeedVideoView> DrawFeedVideoViewMap;

    public DrawFeedVideoViewFactory() {
        super(StandardMessageCodec.INSTANCE);
        FLog.i(TAG, "DrawFeedVideoViewFactory construct");
        DrawFeedVideoViewMap = new HashMap<>();
    }

    public void setActivity(Activity activity) {
        FLog.i(TAG, "setActivity");
        this.activity = activity;
    }

    public void setEventSink(EventChannel.EventSink eventSink) {
        FLog.i(TAG, "setEventSink");
        this.eventSink = eventSink;
    }

    public void releaseDrawFeedVideoViewCache() {
        FLog.i(TAG, "releaseDrawFeedVideoViewCache");
        if (DrawFeedVideoViewMap != null) {
            for (Map.Entry<Integer, DrawFeedVideoView> entry : DrawFeedVideoViewMap.entrySet()) {
                DrawFeedVideoView childView = entry.getValue();
                if (childView != null) {
                    childView.releaseAd();
                }
            }
            DrawFeedVideoViewMap.clear();
        }
    }

    @NonNull
    @Override
    public PlatformView create(@NonNull Context context, int id, @Nullable Object args) {
        if (activity == null) {
            FLog.i(TAG, "activity == null");
            return null;
        }
        try {
            final String parameters = (String) args;
            final DrawFeedVideoBean creationParams = DrawFeedVideoBean.parseObject(parameters);
            int uniqueKey = creationParams.getUniqueKey();
            FLog.i(TAG, "create uniqueKey:" + uniqueKey);
            if (uniqueKey != -1 && creationParams.isCache() && DrawFeedVideoViewMap.containsKey(uniqueKey)) {
                DrawFeedVideoView cachedView = DrawFeedVideoViewMap.get(uniqueKey);
                if (cachedView != null) {
                    FLog.i(TAG, "hit cached native view");
                    try {
                        JSONObject jsonObject = new JSONObject();
                        jsonObject.put(Constants.KEY_METHOD, "onRenderSuccess");
                        jsonObject.put(Constants.KEY_VIEW_ID, id);
                        jsonObject.put(Constants.KEY_DRAW_NATIVE_EXPRESS_VIDEO_VIEW_CACHED, true);
                        jsonObject.put(Constants.KEY_AD_TYPE, Constants.AD_TYPE_NATIVE_DRAW_FEED_VIDEO);
                        String result = jsonObject.toString();
                        eventSink.success(result);
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                    return cachedView;
                }
            }
            DrawFeedVideoView DrawFeedVideoView = new DrawFeedVideoView(activity, uniqueKey, creationParams, this.eventSink);
            DrawFeedVideoViewMap.put(uniqueKey, DrawFeedVideoView);
            return DrawFeedVideoView;
        } catch (Throwable throwable) {
            throwable.printStackTrace();
        }
        return null;
    }
}

==> 0.0.10.tar.gz: android/src/main/java/com/yifan/yf_ads/views/draw/DrawFeedVideoViewFactory.java <==
package com.yifan.yf_ads.views.draw;

import android.app.Activity;
import android.content.Context;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.yifan.yf_ads.bean.DrawFeedVideoBean;
import com.yifan.yf_ads.utils.Constants;
import com.yifan.yf_ads.utils.FLog;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.StandardMessageCodec;
import io.flutter.plugin.platform.PlatformView;
import io.flutter.plugin.platform.PlatformViewFactory;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/26 14:38
 **/
public class DrawFeedVideoViewFactory extends PlatformViewFactory {
    private EventChannel.EventSink eventSink;
    private Activity activity;
    private final String TAG = "DrawFeedVideoViewFactory";
    private Map<String, DrawFeedVideoView> DrawFeedVideoViewMap;

    public DrawFeedVideoViewFactory() {
        super(StandardMessageCodec.INSTANCE);
        FLog.i(TAG, "DrawFeedVideoViewFactory construct");
        DrawFeedVideoViewMap = new HashMap<>();
    }

    public void setActivity(Activity activity) {
        FLog.i(TAG, "setActivity");
        this.activity = activity;
    }

    public void setEventSink(EventChannel.EventSink eventSink) {
        FLog.i(TAG, "setEventSink");
        this.eventSink = eventSink;
    }

    public void releaseDrawFeedVideoViewCache() {
        FLog.i(TAG, "releaseDrawFeedVideoViewCache");
        if (DrawFeedVideoViewMap != null) {
            for (Map.Entry<String, DrawFeedVideoView> entry : DrawFeedVideoViewMap.entrySet()) {
                DrawFeedVideoView childView = entry.getValue();
                if (childView != null) {
                    childView.releaseAd();
                }
            }
            DrawFeedVideoViewMap.clear();
        }
    }

    @NonNull
    @Override
    public PlatformView create(@NonNull Context context, int id, @Nullable Object args) {
        if (activity == null) {
            FLog.i(TAG, "activity == null");
            return null;
        }
        try {
            final String parameters = (String) args;
            final DrawFeedVideoBean creationParams = DrawFeedVideoBean.parseObject(parameters);
            String uniqueKey = creationParams.getUniqueKey();
            FLog.i(TAG, "create uniqueKey:" + uniqueKey);
            if (uniqueKey.equals("-1") && creationParams.isCache() && DrawFeedVideoViewMap.containsKey(uniqueKey)) {
                DrawFeedVideoView cachedView = DrawFeedVideoViewMap.get(uniqueKey);
                if (cachedView != null) {
                    FLog.i(TAG, "hit cached native view");
                    try {
                        JSONObject jsonObject = new JSONObject();
                        jsonObject.put(Constants.KEY_METHOD, "onRenderSuccess");
                        jsonObject.put(Constants.KEY_VIEW_ID, id);
                        jsonObject.put(Constants.KEY_DRAW_NATIVE_EXPRESS_VIDEO_VIEW_CACHED, true);
                        jsonObject.put(Constants.KEY_AD_TYPE, Constants.AD_TYPE_NATIVE_DRAW_FEED_VIDEO);
                        String result = jsonObject.toString();
                        eventSink.success(result);
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                    return cachedView;
                }
            }
            DrawFeedVideoView DrawFeedVideoView = new DrawFeedVideoView(activity, uniqueKey, creationParams, this.eventSink);
            DrawFeedVideoViewMap.put(uniqueKey, DrawFeedVideoView);
            return DrawFeedVideoView;
        } catch (Throwable throwable) {
            throwable.printStackTrace();
        }
        return null;
    }
}
